@@ -7,15 +7,9 @@
  *
  */
 #ifdef PSP_ENABLE_PYTHON
-
-#include <pybind11/pybind11.h>
-#include <pybind11/stl.h>
-#include <perspective/base.h>
-#include <perspective/binding.h>
-#include <perspective/python/base.h>
-#include <perspective/python/utils.h>
 #include <perspective/python/view.h>
 
+
 namespace perspective {
 namespace binding {
 
