@@ -12,6 +12,7 @@ import numpy as np
 import pandas as pd
 from datetime import date, datetime
 from dateutil import tz
+from pytest import mark
 from perspective.table import Table
 
 LOCAL_DATETIMES = [
@@ -236,6 +237,28 @@ if os.name != 'nt':
                 datetime(1969, 12, 31, 19, 0)
             ]
 
+        @mark.skip
+        def test_table_datetime_max(self):
+            data = {
+                "a": [datetime.max]
+            }
+            table = Table(data)
+
+            # lol - result is converted from UTC to EST (local time)
+            assert table.view().to_dict()["a"] == [
+                datetime(9999, 12, 31, 18, 59, 59)
+            ]
+
+        @mark.skip
+        def test_table_datetime_max_df(self):
+            data = pd.DataFrame({
+                "a": [datetime.max]
+            })
+            table = Table(data)
+            assert table.view().to_dict()["a"] == [
+                datetime(9999, 12, 31, 18, 59, 59)
+            ]
+
     class TestTableDateTimeUTCToLocal(object):
 
         def teardown_method(self):
@@ -1016,6 +1039,300 @@ if os.name != 'nt':
 
             assert table.view().to_dict()["a"] == [d.astimezone(ACT).replace(tzinfo=None) for d in data["a"]]
 
+    class TestTableDateTimeRowColumnPaths(object):
+        """Assert correctness of row and column paths in different timezones."""
+        def setup_method(self):
+            # To make sure that local times are not changed, set timezone to EST
+            os.environ["TZ"] = "US/Eastern"
+            time.tzset()
+
+        def teardown_method(self):
+            # Set timezone to UTC, always
+            os.environ["TZ"] = "UTC"
+            time.tzset()
+
+        def test_table_row_pivot_datetime_row_path_local_time_EST(self):
+            """Make sure that string datetimes generated in Python are in
+            local time and not UTC."""
+            data = {
+                "a": LOCAL_DATETIMES,
+                "b": [i for i in range(len(LOCAL_DATETIMES))]
+            }
+
+            table = Table(data)
+
+            view = table.view(row_pivots=["a"])
+            assert view.to_columns() == {
+                "__ROW_PATH__": [
+                    [],
+                    [datetime(2019, 1, 11, 0, 10, 20)],
+                    [datetime(2019, 1, 11, 11, 10, 20)],
+                    [datetime(2019, 1, 11, 19, 10, 20)],
+                ],
+                "a": [3, 1, 1, 1],
+                "b": [3, 0, 1, 2]
+            }
+
+        def test_table_row_pivot_datetime_row_path_UTC(self):
+            """Make sure that string datetimes generated in Python are in
+            UTC if the timezone is UTC.
+            
+            Set the timezone before creating the table so that the local
+            datetime is in the intended timezone, as this test asserts that
+            paths in the same timezone are not edited to UTC."""
+            os.environ["TZ"] = "UTC"
+            time.tzset()
+
+            data = {
+                "a": LOCAL_DATETIMES,
+                "b": [i for i in range(len(LOCAL_DATETIMES))]
+            }
+
+            table = Table(data)
+
+            view = table.view(row_pivots=["a"])
+            assert view.to_columns() == {
+                "__ROW_PATH__": [
+                    [],
+                    [datetime(2019, 1, 11, 0, 10, 20)],
+                    [datetime(2019, 1, 11, 11, 10, 20)],
+                    [datetime(2019, 1, 11, 19, 10, 20)],
+                ],
+                "a": [3, 1, 1, 1],
+                "b": [3, 0, 1, 2]
+            }
+
+        def test_table_row_pivot_datetime_row_path_CST(self):
+            """Make sure that string datetimes generated in Python are in
+            CST if the timezone is CST."""
+            os.environ["TZ"] = "US/Central"
+            time.tzset()
+
+            data = {
+                "a": LOCAL_DATETIMES,
+                "b": [i for i in range(len(LOCAL_DATETIMES))]
+            }
+
+            table = Table(data)
+
+            view = table.view(row_pivots=["a"])
+            assert view.to_columns() == {
+                "__ROW_PATH__": [
+                    [],
+                    [datetime(2019, 1, 11, 0, 10, 20)],
+                    [datetime(2019, 1, 11, 11, 10, 20)],
+                    [datetime(2019, 1, 11, 19, 10, 20)],
+                ],
+                "a": [3, 1, 1, 1],
+                "b": [3, 0, 1, 2]
+            }
+
+        def test_table_row_pivot_datetime_row_path_PST(self):
+            """Make sure that string datetimes generated in Python are in
+            CST if the timezone is CST."""
+            os.environ["TZ"] = "US/Pacific"
+            time.tzset()
+
+            data = {
+                "a": LOCAL_DATETIMES,
+                "b": [i for i in range(len(LOCAL_DATETIMES))]
+            }
+
+            table = Table(data)
+
+            view = table.view(row_pivots=["a"])
+            assert view.to_columns() == {
+                "__ROW_PATH__": [
+                    [],
+                    [datetime(2019, 1, 11, 0, 10, 20)],
+                    [datetime(2019, 1, 11, 11, 10, 20)],
+                    [datetime(2019, 1, 11, 19, 10, 20)],
+                ],
+                "a": [3, 1, 1, 1],
+                "b": [3, 0, 1, 2]
+            }
+
+    class TestTableDateTimeComputedColumns(object):
+        """Assert correctness of datetime-related computed columns in
+        different timezones."""
+        def setup_method(self):
+            # To make sure that local times are not changed, set timezone to EST
+            os.environ["TZ"] = "US/Eastern"
+            time.tzset()
+
+        def teardown_method(self):
+            # Set timezone to UTC, always
+            os.environ["TZ"] = "UTC"
+            time.tzset()
+
+        def test_table_hour_of_day_in_EST(object):
+            computed_columns = [{
+                "inputs": ["a"],
+                "column": "computed",
+                "computed_function_name": "hour_of_day"
+            }]
+
+            data = {
+                "a": LOCAL_DATETIMES
+            }
+
+            table = Table(data)
+            view = table.view(computed_columns=computed_columns)
+            result = view.to_dict()
+            assert result["computed"] == [0, 11, 19]
+
+        def test_table_hour_of_day_in_CST(object):
+            os.environ["TZ"] = "US/Central"
+            time.tzset()
+
+            computed_columns = [{
+                "inputs": ["a"],
+                "column": "computed",
+                "computed_function_name": "hour_of_day"
+            }]
+
+            data = {
+                "a": LOCAL_DATETIMES
+            }
+
+            table = Table(data)
+            view = table.view(computed_columns=computed_columns)
+            result = view.to_dict()
+            assert result["computed"] == [0, 11, 19]
+
+        def test_table_hour_of_day_in_PST(object):
+            os.environ["TZ"] = "US/Pacific"
+            time.tzset()
+
+            computed_columns = [{
+                "inputs": ["a"],
+                "column": "computed",
+                "computed_function_name": "hour_of_day"
+            }]
+
+            data = {
+                "a": LOCAL_DATETIMES
+            }
+
+            table = Table(data)
+            view = table.view(computed_columns=computed_columns)
+            result = view.to_dict()
+            assert result["computed"] == [0, 11, 19]
+
+        def test_table_day_of_week_edge_in_EST(object):
+            """Make sure edge cases are fixed for day of week - if a local
+            time converted to UTC is in the next day, theday of week
+            computation needs to be in local time."""
+            computed_columns = [{
+                "inputs": ["a"],
+                "column": "computed",
+                "computed_function_name": "day_of_week"
+            }]
+
+            data = {
+                "a": [datetime(2020, 1, 31, 23, 59)]
+            }
+
+            table = Table(data)
+            view = table.view(computed_columns=computed_columns)
+            result = view.to_dict()
+            assert result["computed"] == ["6 Friday"]
+
+        def test_table_day_of_week_edge_in_CST(object):
+            os.environ["TZ"] = "US/Central"
+            time.tzset()
+
+            computed_columns = [{
+                "inputs": ["a"],
+                "column": "computed",
+                "computed_function_name": "day_of_week"
+            }]
+
+            data = {
+                "a": [datetime(2020, 1, 31, 23, 59)]
+            }
+
+            table = Table(data)
+            view = table.view(computed_columns=computed_columns)
+            result = view.to_dict()
+            assert result["computed"] == ["6 Friday"]
+
+        def test_table_day_of_week_edge_in_PST(object):
+            os.environ["TZ"] = "US/Pacific"
+            time.tzset()
+
+            computed_columns = [{
+                "inputs": ["a"],
+                "column": "computed",
+                "computed_function_name": "day_of_week"
+            }]
+
+            data = {
+                "a": [datetime(2020, 1, 31, 23, 59)]
+            }
+
+            table = Table(data)
+            view = table.view(computed_columns=computed_columns)
+            result = view.to_dict()
+            assert result["computed"] == ["6 Friday"]
+
+        def test_table_month_of_year_edge_in_EST(object):
+            """Make sure edge cases are fixed for month of year - if a local
+            time converted to UTC is in the next month, the month of year
+            computation needs to be in local time."""
+            computed_columns = [{
+                "inputs": ["a"],
+                "column": "computed",
+                "computed_function_name": "month_of_year"
+            }]
+
+            data = {
+                "a": [datetime(2020, 1, 31, 23, 59)]
+            }
+
+            table = Table(data)
+            view = table.view(computed_columns=computed_columns)
+            result = view.to_dict()
+            assert result["computed"] == ["01 January"]
+
+        def test_table_month_of_year_edge_in_CST(object):
+            os.environ["TZ"] = "US/Central"
+            time.tzset()
+
+            computed_columns = [{
+                "inputs": ["a"],
+                "column": "computed",
+                "computed_function_name": "month_of_year"
+            }]
+
+            data = {
+                "a": [datetime(2020, 1, 31, 23, 59)]
+            }
+
+            table = Table(data)
+            view = table.view(computed_columns=computed_columns)
+            result = view.to_dict()
+            assert result["computed"] == ["01 January"]
+
+        def test_table_month_of_year_edge_in_PST(object):
+            os.environ["TZ"] = "US/Pacific"
+            time.tzset()
+
+            computed_columns = [{
+                "inputs": ["a"],
+                "column": "computed",
+                "computed_function_name": "month_of_year"
+            }]
+
+            data = {
+                "a": [datetime(2020, 1, 31, 23, 59)]
+            }
+
+            table = Table(data)
+            view = table.view(computed_columns=computed_columns)
+            result = view.to_dict()
+            assert result["computed"] == ["01 January"]
+
 
 class TestTableDateTimePivots(object):
 
@@ -1029,18 +1346,18 @@ class TestTableDateTimePivots(object):
         assert view.to_columns() == {
             "__ROW_PATH__": [
                 [],
-                ['2020-01-15'],
-                ['2020-02-15'],
-                ['2020-03-15'],
-                ['2020-04-15'],
-                ['2020-05-15'],
-                ['2020-06-15'],
-                ['2020-07-15'],
-                ['2020-08-15'],
-                ['2020-09-15'],
-                ['2020-10-15'],
-                ['2020-11-15'],
-                ['2020-12-15']
+                [datetime(2020, 1, 15, 0, 0)],
+                [datetime(2020, 2, 15, 0, 0)],
+                [datetime(2020, 3, 15, 0, 0)],
+                [datetime(2020, 4, 15, 0, 0)],
+                [datetime(2020, 5, 15, 0, 0)],
+                [datetime(2020, 6, 15, 0, 0)],
+                [datetime(2020, 7, 15, 0, 0)],
+                [datetime(2020, 8, 15, 0, 0)],
+                [datetime(2020, 9, 15, 0, 0)],
+                [datetime(2020, 10, 15, 0, 0)],
+                [datetime(2020, 11, 15, 0, 0)],
+                [datetime(2020, 12, 15, 0, 0)]
             ],
             "a": [12, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1],
             "b": [78, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12]
@@ -1056,18 +1373,18 @@ class TestTableDateTimePivots(object):
         assert view.to_columns() == {
             "__ROW_PATH__": [
                 [],
-                ['2020-01-15'],
-                ['2020-02-15'],
-                ['2020-03-15'],
-                ['2020-04-15'],
-                ['2020-05-15'],
-                ['2020-06-15'],
-                ['2020-07-15'],
-                ['2020-08-15'],
-                ['2020-09-15'],
-                ['2020-10-15'],
-                ['2020-11-15'],
-                ['2020-12-15']
+                [datetime(2020, 1, 15, 0, 0)],
+                [datetime(2020, 2, 15, 0, 0)],
+                [datetime(2020, 3, 15, 0, 0)],
+                [datetime(2020, 4, 15, 0, 0)],
+                [datetime(2020, 5, 15, 0, 0)],
+                [datetime(2020, 6, 15, 0, 0)],
+                [datetime(2020, 7, 15, 0, 0)],
+                [datetime(2020, 8, 15, 0, 0)],
+                [datetime(2020, 9, 15, 0, 0)],
+                [datetime(2020, 10, 15, 0, 0)],
+                [datetime(2020, 11, 15, 0, 0)],
+                [datetime(2020, 12, 15, 0, 0)]
             ],
             "index": [66, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11],
             "a": [12, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1],
